==> savane-1.0.4.1.tar.gz: savane/frontend/php/people/viewgpg.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: viewgpg.php,v 1.10 2004/06/08 14:54:12 zerodeux Exp $
#
#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";

if ($user_id) 
{
  /*
		Fill in the info to create a job
  */
	
  echo $HTML->header(array('title'=>_("View a GPG Key")));

  #for security, include group_id
  $sql="SELECT * FROM user WHERE user_id='$user_id'";
  $result=db_query($sql);
  if (!$result || db_numrows($result) < 1) 
    {
      echo db_error();
      fb(_("User fetch FAILED"));
      echo '<h2>'._("No Such User").'</h2>';

    } 
  else
    {
      echo '<h3>';
      printf (_("%s's GPG Key:"),db_result($result,0,'user_name'));
      echo '</h3>';

      if (!db_result($result,0,'gpg_key')) 
	{
	  echo '<p>'._("This user has not set his/her GPG Key").'</p>';
	} 
      else
	{
	  echo '<code>'.nl2br(utils_make_links(db_result($result,0,'gpg_key'))).'</code>';
	}
    }

  echo $HTML->footer(array());

} 
else
{
  /*
		Not logged in or insufficient privileges
  */
  exit_error(_("Error"),_("user_id not found."));
}

?>

==> savane-1.0.5a.tar.gz: savane/frontend/php/people/viewgpg.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: viewgpg.php,v 1.11 2004/10/30 02:18:40 sonicmctails Exp $
#
#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# This program is free software; you can reprintdistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";

if ($user_id) 
{
  /*
		Fill in the info to create a job
  */
	
  echo site_header(array('title'=>_("View a GPG Key")));

  #for security, include group_id
  $sql="SELECT * FROM user WHERE user_id='$user_id'";
  $result=db_query($sql);
  if (!$result || db_numrows($result) < 1) 
    {
      echo db_error();
      fb(_("User fetch FAILED"));
      echo '<h2>'._("No Such User").'</h2>';

    } 
  else
    {
      echo '<h3>';
      printf (_("%s's GPG Key:"),db_result($result,0,'user_name'));
      echo '</h3>';

      if (!db_result($result,0,'gpg_key')) 
	{
	  echo '<p>'._("This user has not set his/her GPG Key").'</p>';
	} 
      else
	{
	  echo '<code>'.nl2br(utils_make_links(db_result($result,0,'gpg_key'))).'</code>';
	}
    }

  echo site_footer(array());

} 
else
{
  /*
		Not logged in or insufficient privileges
  */
  exit_error(_("Error"),_("user_id not found."));
}

?>
